{% load filer_admin_tags i18n static %}
    <section class="image-info image-info-detail">
        <div class="image-info-title"></div>
        <div class="image-details-left">
            <div class="image-preview-container">
                {% file_icon original detail=True %}
                <div class="text-left button-group">
                {% if original.file.exists %}
                    <a href="{{ original.url }}" target="_blank" class="button" download="{{ original.original_filename }}" rel="noopener noreferrer">
                        <span class="icon fa fa-download filer-icon filer-icon-download"></span>&nbsp;
                        <span>{% translate "Download" %}</span>
                    </a>
                    {% if original.mime_maintype == 'image' and "svg" not in original.mime_type %}
                    <a href="{{ original.url }}" target="_blank" rel="noopener noreferrer" class="button">
                        <span>{% translate "Expand" %}</span>&nbsp;
                        <span class="icon filer-icon filer-icon-expand fa fa-expand"></span>
                    </a>
                    {% endif %}
                {% else %}
                    <span class="warning">{% translate "File is missing" %}</span>
                {% endif %}
                </div>
            </div>
        </div>
        <div class="image-details-right">
            {% if original.file_type or original.modified_at or original.uploaded_at or original.width or original.height or original.size %}
                <dl class="image-details">
                    {% if original.file_type %}
                        <dt>{% translate "Type" %}</dt>
                        <dd>{{ original.extension|upper }} {{ original.file_type }} ({{ original.mime_type }})</dd>
                    {% endif %}
                    {% if original.width or original.height %}
                        <dt>{% translate "Size" %}</dt>
                        <dd>{{ original.width|floatformat }}x{{ original.height|floatformat }} px</dd>
                    {% endif %}
                    {% if original.size %}
                        <dt>{% translate "File-size" %}</dt>
                        <dd>{{ original.size|filesizeformat }}</dd>
                    {% endif %}
                    {% if original.modified_at %}
                        <dt>{% translate "Modified" %}</dt>
                        <dd>{{ original.modified_at }}</dd>
                    {% endif %}
                    {% if original.uploaded_at %}
                        <dt>{% translate "Created" %}</dt>
                        <dd>{{ original.uploaded_at }}</dd>
                    {% endif %}
                    {% if original.owner %}
                        <dt>{% translate "Owner" %}</dt>
                        <dd><strong>{{ original.owner }}</strong></dd>
                    {% endif %}
                </dl>
            {% endif %}
        </div>
    </section>
